==> campsite-2.4.1.tbz: campsite/www-common/html/priv/lang/cz/api.php <==
<?php
regGS("Cannot create file \"$1\"", "");
regGS("The IP address group $1 has been deleted.", "");
regGS("IP Group $1 added for user $2", "");
regGS("User permissions for $1 changed", "");
regGS("Section $1 deleted. (Issue: $2, Publication: $3)", "");
regGS("Section $1 added. (Issue: $2, Publication: $3)", "");
regGS("Issue $1 changed status to $2", "");
regGS("User type $1 deleted", "");
regGS("User type $1 added", "");
regGS("Topic $1 added to article", "Téma $1 bylo přidáno k článku");
regGS("Last", "");
regGS("First", "");
regGS("Changed image properties of $1", "Změnit vlastnosti obrázku");
regGS("Article topic $1 deleted", "Téma článku $1 bylo smazáno");
regGS("Article #$1 \"$2\" ($3) created.", "");
regGS("Article #$1 \"$2\" ($3) translated to \"$5\" ($4)", "");
regGS("Article #$1 \"$2\" ($3) copied to Article #$3. ", "");
regGS("Article #$1: \"$2\" status changed from $3 to $4.", "");
regGS("Article #$1: \"$2\" ($3) deleted.", "");
regGS("Text", "");
regGS("Article body", "");
regGS("The default subscription time for $1 has been added.", "Předplatné období $1 bylo úspěšně přidáno");
regGS("The image $1 has been added.", "Obrázek $1 byl úspěšně přidán");
regGS("Image $1 deleted", "Obrázek $1 byl smazán");
regGS("Publication $1 changed", "Publikace $1 změněna");
regGS("Publication $1 deleted", "Publikace $1 byla smazána");
regGS("Publication $1 added", "Publikace $1 byla přidána");
regGS("Issue $1 from publication $2 deleted", "Vydání $1 v publikaci $2 bylo smazáno");
regGS("Issue $1 added in publication $2", "Vydání $1 bylo přidáno v publikaci $2");
regGS("The article type $1 has been deleted.", "Typ článku $1 byl smazán");
regGS("The article type $1 has been added.", "Typ článku $1 byl přidán");
regGS("Article type field $1 created", "Pole typu článku $1 bylo vytvořeno");
regGS("Article type field $1 deleted", "Pole typu článku $1 bylo smazáno");
regGS("Language $1 added", "Jazyk $1 byl přidán");
regGS("Language $1 deleted", "$1 jazyk byl smazán");
regGS("Language $1 modified", "Jazyk $1 byl upraven");
regGS("Country $1 added", "Země $1 byla přidána");
regGS("Country $1 deleted", "Země $1 byla smazána");
regGS("Country name $1 changed", "Název země $1 byl změněn");
regGS("The user account $1 has been deleted.", "Uživatelský účet $1 byl smazán");
regGS("Password changed for $1", "Heslo bylo změněno na $1");
regGS("User account $1 created", "Uživatelský účet $1 byl vytvořen");
regGS("Template $1 uploaded", "Šablona $1 byla nahrána");
?>

==> campsite-2.6.1.tbz: campsite/www-common/html/priv/lang/cz/api.php <==
<?php 
regGS("Template $1 no longer exists!", "");
regGS("The file uploaded is not an image.", "");
regGS("Field $1 updated", "");
regGS("Could not delete record from the database.", "");
regGS("template path", "");
regGS("short names", "");
regGS("Unable to fetch image from remote server.", "");
regGS("The article type field $1 has been renamed to $2.", "");
regGS("The article type $1 has been renamed to $2.", "");
regGS("Article type field $1 changed", "");
regGS("Article Type $1 translation updated", "");
regGS("The IP address group $1 has been deleted.", "");
regGS("IP Group $1 added for user $2", "");
regGS("User permissions for $1 changed", "");
regGS("Section $1 deleted. (Issue: $2, Publication: $3)", "");
regGS("Section $1 added. (Issue: $2, Publication: $3)", "");
regGS("Issue $1 changed status to $2", "");
regGS("User type $1 deleted", "");
regGS("User type $1 added", "");
regGS("Topic $1 added to article", "Téma $1 bylo přidáno k článku");
regGS("Last", "");
regGS("First", "");
regGS("Changed image properties of $1", "Změnit vlastnosti obrázku");
regGS("Article topic $1 deleted", "Téma článku $1 bylo smazáno");
regGS("Article #$1 \"$2\" ($3) created.", "");
regGS("Article #$1 \"$2\" ($3) translated to \"$5\" ($4)", "");
regGS("Article #$1 \"$2\" ($3) copied to Article #$3. ", "");
regGS("Article #$1: \"$2\" status changed from $3 to $4.", "");
regGS("Article #$1: \"$2\" ($3) deleted.", "");
regGS("Single-line Text", "");
regGS("Multi-line Text with WYSIWYG", "");
regGS("The default subscription time for $1 has been added.", "Předplatné období $1 bylo úspěšně přidáno");
regGS("Image $1 linked to article $2", "");
regGS("Image $1 unlinked from $2", "");
regGS("The image $1 has been added.", "Obrázek $1 byl úspěšně přidán");
regGS("Image $1 deleted", "Obrázek $1 byl smazán");
regGS("Publication $1 changed", "Publikace $1 změněna");
regGS("Publication $1 deleted", "Publikace $1 byla smazána");
regGS("Publication $1 added", "Publikace $1 byla přidána");
regGS("Issue $1 from publication $2 deleted", "Vydání $1 v publikaci $2 bylo smazáno");
regGS("Issue $1 added in publication $2", "Vydání $1 bylo přidáno v publikaci $2");
regGS("The article type $1 has been deleted.", "Typ článku $1 byl smazán");
regGS("The article type $1 has been added.", "Typ článku $1 byl přidán");
regGS("Article type field $1 created", "Pole typu článku $1 bylo vytvořeno");
regGS("Article type field $1 deleted", "Pole typu článku $1 bylo smazáno");
regGS("Language $1 added", "Jazyk $1 byl přidán");
regGS("Language $1 deleted", "$1 jazyk byl smazán");
regGS("Language $1 modified", "Jazyk $1 byl upraven");
regGS("Country $1 added", "Země $1 byla přidána");
regGS("Country $1 deleted", "Země $1 byla smazána");
regGS("Country name $1 changed", "Název země $1 byl změněn");
regGS("The user account $1 has been deleted.", "Uživatelský účet $1 byl smazán");
regGS("Password changed for $1", "Heslo bylo změněno na $1");
regGS("User account $1 created", "Uživatelský účet $1 byl vytvořen");
regGS("Template $1 uploaded", "Šablona $1 byla nahrána");
regGS("URL \"$1\" is invalid or is not an image.", "URL \"$1\" není platné, nebo se nejedná o obrázek.");
regGS("URL \"$1\" is not an image.", "URL \"$1\" není obrázek");
regGS("Topic $1 added", "Téma $1 bylo přidáno");
regGS("Topic $1 deleted", "Téma $1 bylo smazáno");
regGS("Topic $1 updated", "Téma $1 bylo obnoveno");
?>
